[damned-lies] Fixed a file extension check



commit 4b57467b09dc21b6b4eca135bdf98ff09010cbb2
Author: Claude Paroz <claude 2xlibre net>
Date:   Mon Apr 2 11:58:32 2018 +0200

    Fixed a file extension check
    
    Should also fix bug #749860

 stats/utils.py |    7 +++++--
 1 files changed, 5 insertions(+), 2 deletions(-)
---
diff --git a/stats/utils.py b/stats/utils.py
index c611578..80baa69 100644
--- a/stats/utils.py
+++ b/stats/utils.py
@@ -443,8 +443,11 @@ def generate_doc_pot_file(branch, domain):
                 files.append(Path("C", index_page))
                 break
         if not files:
-            # Last try: only one xml file in C/...
-            xml_files = [f for f in doc_format.source_files(force_all=True) if f.endswith(".xml")]
+            # Last try: only one xml/docbook file in C/...
+            xml_files = [
+                f for f in doc_format.source_files(force_all=True)
+                if f.suffix in (".xml", ".docbook")
+            ]
             if len(xml_files) == 1:
                 files.append(xml_files[0])
             else:


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]